@@ -52,6 +52,12 @@ def sleeping_task(seconds):
     sleep(seconds)
 
 
+@kuyruk.task(queue='kuyruk2')
+def task_sending_task():
+    print 'sending print task'
+    print_task('came from task_sending_task')
+
+
 # Another kuyruk instance for testing before and after task decorators
 kuyruk2 = Kuyruk()
 
